{% load static %}<!doctype html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>
      {% block head_title %}
        {% if title %}{{ title }}{% if site_title %} - {% endif %}{% endif %}
        {{ site_title }}
      {% endblock %}
    </title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <link rel="stylesheet" href="{% static "django_style/bootstrap/styles.css" %}">
    {% block extra_head %}{% endblock %}
  </head>
  <body{% if STYLE_IS_APP %} class="app"{% endif %}>
    {% block body %}
      {% block header %}
        <nav class="navbar navbar-expand-lg bg-body-tertiary{% if STYLE_IS_APP %} border-bottom{% endif %}">
          <div class="container{% if STYLE_IS_APP %}-fluid px-4{% endif %}"">
            {% if site_title %}
              <a class="navbar-brand" href="#">{{ site_title }}</a>
            {% endif %}
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
              <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarSupportedContent">
              <ul class="navbar-nav ms-auto mb-2 mb-lg-0 justify-content-end">
                {% block site_nav_items %}
                  {% for nav_item in site_nav %}
                    <li class="nav-item">
                      <a
                        class="nav-link{% if nav_item.url == request.path %} active" aria-current="page{% endif %}"
                        href="{{ nav_item.url }}"
                      >{{ nav_item.label }}</a>
                    </li>
                  {% endfor %}
                {% endblock %}
              </ul>
            </div>
          </div>
        </nav>
      {% endblock %}

      <main class="container{% if STYLE_IS_APP %}-fluid{% else %} my-4{% endif %}">
        {% block main %}
          {% block title %}
            <h1>{{ title }}</h1>
          {% endblock %}
          {% block content %}{% endblock %}
        {% endblock %}
      </main>

      {% block footer %}
        <footer class="container{% if STYLE_IS_APP %}-fluid px-4{% endif %} border-top py-3">
          {% if footer_nav %}
            <nav>
                <ul class="nav">
                  {% block footer_nav_items %}
                    {% for nav_item in footer_nav %}
                      <li class="nav-item">
                        <a class="nav-link" href="{{ nav_item.url }}">{{ nav_item.label }}</a>
                      </li>
                    {% endfor %}
                  {% endblock %}
                </ul>
              </div>
            </nav>
          {% endif %}
        </footer>
      {% endblock %}

      <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js" integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz" crossorigin="anonymous"></script>
    {% endblock %}
  </body>
</html>
